@@ -20,7 +20,9 @@ the :class:`sklearn.preprocessing.SplineTransformer` class and its
 # We start by loading the data from the OpenML repository.
 from sklearn.datasets import fetch_openml
 
-bike_sharing = fetch_openml("Bike_Sharing_Demand", version=2, as_frame=True)
+bike_sharing = fetch_openml(
+    "Bike_Sharing_Demand", version=2, as_frame=True, parser="pandas"
+)
 df = bike_sharing.frame
 
 # %%
@@ -33,9 +35,8 @@ df = bike_sharing.frame
 # demand around the middle of the days:
 import matplotlib.pyplot as plt
 
-
 fig, ax = plt.subplots(figsize=(12, 4))
-average_week_demand = df.groupby(["weekday", "hour"]).mean()["count"]
+average_week_demand = df.groupby(["weekday", "hour"])["count"].mean()
 average_week_demand.plot(ax=ax)
 _ = ax.set(
     title="Average hourly bike demand during the week",
@@ -179,12 +180,11 @@ X.iloc[train_4]
 #
 # The numerical variables need no preprocessing and, for the sake of simplicity,
 # we only try the default hyper-parameters for this model:
-from sklearn.pipeline import make_pipeline
-from sklearn.preprocessing import OrdinalEncoder
 from sklearn.compose import ColumnTransformer
 from sklearn.ensemble import HistGradientBoostingRegressor
 from sklearn.model_selection import cross_validate
-
+from sklearn.pipeline import make_pipeline
+from sklearn.preprocessing import OrdinalEncoder
 
 categorical_columns = [
     "weather",
@@ -207,11 +207,16 @@ gbrt_pipeline = make_pipeline(
             ("categorical", ordinal_encoder, categorical_columns),
         ],
         remainder="passthrough",
+        # Use short feature names to make it easier to specify the categorical
+        # variables in the HistGradientBoostingRegressor in the next
+        # step of the pipeline.
+        verbose_feature_names_out=False,
     ),
     HistGradientBoostingRegressor(
-        categorical_features=range(4),
+        categorical_features=categorical_columns,
+        random_state=42,
     ),
-)
+).set_output(transform="pandas")
 
 # %%
 #
@@ -255,13 +260,12 @@ evaluate(gbrt_pipeline, X, y, cv=ts_cv)
 # For consistency, we scale the numerical features to the same 0-1 range using
 # class:`sklearn.preprocessing.MinMaxScaler`, although in this case it does not
 # impact the results much because they are already on comparable scales:
-from sklearn.preprocessing import OneHotEncoder
-from sklearn.preprocessing import MinMaxScaler
-from sklearn.linear_model import RidgeCV
 import numpy as np
 
+from sklearn.linear_model import RidgeCV
+from sklearn.preprocessing import MinMaxScaler, OneHotEncoder
 
-one_hot_encoder = OneHotEncoder(handle_unknown="ignore", sparse=False)
+one_hot_encoder = OneHotEncoder(handle_unknown="ignore", sparse_output=False)
 alphas = np.logspace(-6, 6, 25)
 naive_linear_pipeline = make_pipeline(
     ColumnTransformer(
@@ -612,9 +616,8 @@ cyclic_spline_linear_pipeline[:-1].transform(X).shape
 # However, it is possible to use the `PolynomialFeatures` class on coarse
 # grained spline encoded hours to model the "workingday"/"hours" interaction
 # explicitly without introducing too many new variables:
-from sklearn.preprocessing import PolynomialFeatures
 from sklearn.pipeline import FeatureUnion
-
+from sklearn.preprocessing import PolynomialFeatures
 
 hour_workday_interaction = make_pipeline(
     ColumnTransformer(
@@ -661,7 +664,6 @@ evaluate(cyclic_spline_interactions_pipeline, X, y, cv=ts_cv)
 # polynomial kernel expansion. Let us try the latter:
 from sklearn.kernel_approximation import Nystroem
 
-
 cyclic_spline_poly_pipeline = make_pipeline(
     cyclic_spline_transformer,
     Nystroem(kernel="poly", degree=2, n_components=300, random_state=0),
@@ -768,30 +770,41 @@ _ = ax.legend()
 #
 # Let us finally get a more quantative look at the prediction errors of those
 # three models using the true vs predicted demand scatter plots:
-fig, axes = plt.subplots(ncols=3, figsize=(12, 4), sharey=True)
-fig.suptitle("Non-linear regression models")
+from sklearn.metrics import PredictionErrorDisplay
+
+fig, axes = plt.subplots(nrows=2, ncols=3, figsize=(13, 7), sharex=True, sharey="row")
+fig.suptitle("Non-linear regression models", y=1.0)
 predictions = [
     one_hot_poly_predictions,
     cyclic_spline_poly_predictions,
     gbrt_predictions,
 ]
 labels = [
-    "One hot + polynomial kernel",
-    "Splines + polynomial kernel",
-    "Gradient Boosted Trees",
+    "One hot +\npolynomial kernel",
+    "Splines +\npolynomial kernel",
+    "Gradient Boosted\nTrees",
 ]
-for ax, pred, label in zip(axes, predictions, labels):
-    ax.scatter(y.iloc[test_0].values, pred, alpha=0.3, label=label)
-    ax.plot([0, 1], [0, 1], "--", label="Perfect model")
-    ax.set(
-        xlim=(0, 1),
-        ylim=(0, 1),
-        xlabel="True demand",
-        ylabel="Predicted demand",
-    )
-    ax.legend()
-
-
+plot_kinds = ["actual_vs_predicted", "residual_vs_predicted"]
+for axis_idx, kind in enumerate(plot_kinds):
+    for ax, pred, label in zip(axes[axis_idx], predictions, labels):
+        disp = PredictionErrorDisplay.from_predictions(
+            y_true=y.iloc[test_0],
+            y_pred=pred,
+            kind=kind,
+            scatter_kwargs={"alpha": 0.3},
+            ax=ax,
+        )
+        ax.set_xticks(np.linspace(0, 1, num=5))
+        if axis_idx == 0:
+            ax.set_yticks(np.linspace(0, 1, num=5))
+            ax.legend(
+                ["Best model", label],
+                loc="upper center",
+                bbox_to_anchor=(0.5, 1.3),
+                ncol=2,
+            )
+        ax.set_aspect("equal", adjustable="box")
+plt.show()
 # %%
 # This visualization confirms the conclusions we draw on the previous plot.
 #
