@@ -32,11 +32,12 @@ We will use USPS digits dataset to reproduce presented in Sect. 4 of [1]_.
 # :func:`~sklearn.datasets.fetch_openml` to get this dataset. In addition, we
 # normalize the dataset such that all pixel values are in the range (0, 1).
 import numpy as np
-from sklearn.datasets import fetch_openml
-from sklearn.preprocessing import MinMaxScaler
-from sklearn.model_selection import train_test_split
 
-X, y = fetch_openml(data_id=41082, as_frame=False, return_X_y=True)
+from sklearn.datasets import fetch_openml
+from sklearn.model_selection import train_test_split
+from sklearn.preprocessing import MinMaxScaler
+
+X, y = fetch_openml(data_id=41082, as_frame=False, return_X_y=True, parser="pandas")
 X = MinMaxScaler().fit_transform(X)
 
 # %%
@@ -98,9 +99,14 @@ plot_digits(
 # uses a radial basis function (RBF) kernel.
 from sklearn.decomposition import PCA, KernelPCA
 
-pca = PCA(n_components=32)
+pca = PCA(n_components=32, random_state=42)
 kernel_pca = KernelPCA(
-    n_components=400, kernel="rbf", gamma=1e-3, fit_inverse_transform=True, alpha=5e-3
+    n_components=400,
+    kernel="rbf",
+    gamma=1e-3,
+    fit_inverse_transform=True,
+    alpha=5e-3,
+    random_state=42,
 )
 
 pca.fit(X_train_noisy)
@@ -130,8 +136,10 @@ plot_digits(
 )
 plot_digits(
     X_reconstructed_kernel_pca,
-    "Kernel PCA reconstruction\n"
-    f"MSE: {np.mean((X_test - X_reconstructed_kernel_pca) ** 2):.2f}",
+    (
+        "Kernel PCA reconstruction\n"
+        f"MSE: {np.mean((X_test - X_reconstructed_kernel_pca) ** 2):.2f}"
+    ),
 )
 
 # %%
